@@ -12,7 +12,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright (C) 2015-present, TBOOX Open Source Group.
+ * Copyright (C) 2015-present, Xmake Open Source Community.
  *
  * @author      ruki
  * @file        poller.h
@@ -26,6 +26,18 @@
  */
 #include "prefix.h"
 
+/* //////////////////////////////////////////////////////////////////////////////////////
+ * types
+ */
+
+// the poller state in wait events
+typedef struct __xm_poller_state_t
+{
+    lua_State*      lua;
+    tb_int_t        events_count;
+
+}xm_poller_state_t;
+
 /* //////////////////////////////////////////////////////////////////////////////////////
  * interfaces
  */
@@ -34,7 +46,7 @@
  *
  * @return          the io poller
  */
-tb_poller_ref_t     xm_io_poller(tb_noarg_t);
+tb_poller_ref_t     xm_io_poller(lua_State* lua);
 
 #endif
 
