@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        link.lua
@@ -22,6 +22,14 @@
 import("core.project.config")
 import("private.tools.vstool")
 
+-- get implib file
+function _get_implibfile(self, opt)
+    local target = opt and opt.target
+    if target and target:type() == "target" then
+        return target:artifactfile("implib")
+    end
+end
+
 -- init it
 function init(self)
 
@@ -137,15 +145,24 @@ function linkargv(self, objectfiles, targetkind, targetfile, flags, opt)
         table.insert(argv, 1, "-lib")
     elseif targetkind == "shared" then
         table.insert(argv, 1, "-dll")
+        local implibfile = _get_implibfile(self, opt)
+        if implibfile then
+            table.insert(argv, "/implib:" .. implibfile)
+        end
     end
     return self:program(), argv
 end
 
 -- link the target file
 function link(self, objectfiles, targetkind, targetfile, flags, opt)
+    opt = opt or {}
 
-    -- ensure the target directory
+    -- ensure the target file directory exists
     os.mkdir(path.directory(targetfile))
+    local implibfile = _get_implibfile(self, opt)
+    if implibfile then
+        os.mkdir(path.directory(implibfile))
+    end
 
     try
     {
@@ -153,6 +170,7 @@ function link(self, objectfiles, targetkind, targetfile, flags, opt)
 
             local toolchain = self:toolchain()
             local program, argv = linkargv(self, objectfiles, targetkind, targetfile, flags, opt)
+
             if toolchain and toolchain:name() == "masm32" then
                 os.iorunv(program, argv, {envs = self:runenvs()})
             else
@@ -177,4 +195,3 @@ function link(self, objectfiles, targetkind, targetfile, flags, opt)
         }
     }
 end
-
