@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      ruki
 -- @file        xmake.lua
@@ -31,7 +31,7 @@ toolchain("gcc" .. suffix)
     set_runtimes("stdc++_static", "stdc++_shared")
 
     set_toolset("cc", "gcc" .. suffix)
-    set_toolset("cxx", "gcc" .. suffix, "g++" .. suffix)
+    set_toolset("cxx", "g++" .. suffix, "gcc" .. suffix)
     set_toolset("ld", "g++" .. suffix, "gcc" .. suffix)
     set_toolset("sh", "g++" .. suffix, "gcc" .. suffix)
     set_toolset("ar", "ar")
@@ -39,7 +39,7 @@ toolchain("gcc" .. suffix)
     set_toolset("objcopy", "objcopy")
     set_toolset("ranlib", "ranlib")
     set_toolset("mm", "gcc" .. suffix)
-    set_toolset("mxx", "gcc" .. suffix, "g++" .. suffix)
+    set_toolset("mxx", "g++" .. suffix, "gcc" .. suffix)
     set_toolset("as", "gcc" .. suffix)
 
     on_check(function (toolchain)
